Plotting workflows — FireWorks 1.2.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- FireWorks 1.2.1 documentation »

# Plotting workflows

Note

You must have networkx and matplotlib installed as optional dependencies in order to use plotting

The plotting feature is in alpha stage of development. You can plot workflows via the command:

    lpad display_wflows -i <FW_ID>

where <FW_ID> corresponds to one of the Firework ids in your workflow.

### Navigation

- index
- modules |
- next |
- previous |
- FireWorks 1.2.1 documentation »